@@ -35,7 +35,6 @@ import requests
 import numpy as np
 import datetime
 
-# import modin.pandas as pd
 import pandas as pd
 import sys
 import json
@@ -175,8 +174,8 @@ class Search:
                 "ticker",
                 "Path",
                 "Filename",
-                "Item",
-                "Item Name",
+                "time_series_description",
+                "time_series_name",
                 "Fiscal Period",
                 "Low",
                 "Mid",
@@ -185,7 +184,7 @@ class Search:
                 "Date",
                 "Link",
             ]
-        ].sort_values(["ticker", "Date", "Item"])
+        ].sort_values(["ticker", "Date", "time_series_description"])
 
     def search_time_series(
         self,
@@ -752,6 +751,111 @@ class ModelSet:
             df.columns = ["help"]
             return df
 
+    def pe_dataset(self, ticker, yahoo_ticker):
+        import canalyst_candas.candas_datareader as cdr
+
+        df_earnings = cdr.get_earnings_and_prices(yahoo_ticker)
+        df_earnings = df_earnings[
+            ["ticker", "earnings_date", "beta_252", "alpha_5_day", "alpha_10_day"]
+        ]
+
+        df_model = self.model_frame(
+            ticker=ticker, is_historical=True, period_duration_type="fiscal_quarter"
+        )
+
+        edq_list = list(
+            cdr.calendar_quarter(df_earnings, "earnings_date", datetime=True)[
+                "earnings_date_CALENDAR_QUARTER"
+            ]
+        )
+        mdq_list = list(
+            df_model.groupby("period_name_sorted")
+            .first()
+            .reset_index()
+            .sort_values("period_name_sorted", ascending=False)["period_name_sorted"]
+        )
+        d = {"earnings_date_q": edq_list[0:24], "period_name_sorted": mdq_list[0:24]}
+        df_dates = pd.DataFrame(d)
+        df_model = pd.merge(df_model, df_dates)
+        df_earnings["earnings_date_q"] = cdr.calendar_quarter(
+            df_earnings, "earnings_date", datetime=True
+        )["earnings_date_CALENDAR_QUARTER"]
+        df_model["price_ticker"] = yahoo_ticker
+        df_model = df_model.drop(columns=["ticker"])
+        df_data = pd.merge(
+            df_model,
+            df_earnings,
+            how="inner",
+            left_on=["price_ticker", "earnings_date_q"],
+            right_on=["ticker", "earnings_date_q"],
+        )
+        df_data["ticker"] = ticker
+        df_data = df_data.drop(
+            columns=[
+                "earnings_dateshift",
+                "earnings_date_CALENDAR_QUARTER",
+                "category_type_slug",
+                "time_series_slug",
+            ]
+        )
+
+        df_data["year_over_year"] = (
+            df_data.sort_values(["time_series_name", "period_end_date"])
+            .groupby(["time_series_name"])
+            .value.pct_change(periods=4)
+        )
+
+        df_data["year_over_year_yoy"] = (
+            df_data.sort_values(["time_series_name", "period_end_date"])
+            .groupby(["time_series_name"])
+            .year_over_year.pct_change(periods=4)
+        )
+
+        df_data["quarter_over_quarter"] = (
+            df_data.sort_values(["time_series_name", "period_end_date"])
+            .groupby(["time_series_name"])
+            .value.pct_change(periods=1)
+        )
+
+        df_data["quarter_over_quarter_yoy"] = (
+            df_data.sort_values(["time_series_name", "period_end_date"])
+            .groupby(["time_series_name"])
+            .quarter_over_quarter.pct_change(periods=4)
+        )
+
+        df1 = df_data.copy()
+        df1["value"] = df1["year_over_year"]
+        df1["time_series_name"] = df1["time_series_name"] + "_year_over_year"
+
+        df2 = df_data.copy()
+        df2["value"] = df2["year_over_year_yoy"]
+        df2["time_series_name"] = df2["time_series_name"] + "_year_over_year_yoy"
+        df3 = df_data.copy()
+        df3["value"] = df3["quarter_over_quarter"]
+        df3["time_series_name"] = df3["time_series_name"] + "_quarter_over_quarter"
+        df4 = df_data.copy()
+        df4["value"] = df4["quarter_over_quarter_yoy"]
+        df4["time_series_name"] = df4["time_series_name"] + "_quarter_over_quarter_yoy"
+        # df_data = df_data.drop(columns=['year_over_year','year_over_year_2','quarter_over_quarter'])
+        # df1 = df1.drop(columns=['year_over_year','year_over_year_2','quarter_over_quarter'])
+        # df2 = df2.drop(columns=['year_over_year','year_over_year_2','quarter_over_quarter'])
+        # df3 = df3.drop(columns=['year_over_year','year_over_year_2','quarter_over_quarter'])
+        df_out = pd.concat([df_data, df1, df2, df3, df4])
+        return df_out[~df_out["value"].isna()]
+
+    def regress_dataframe_time_series_groups(
+        self, df_data=None, y_name="alpha_10_day", return_grouped=True
+    ):
+        ticker = df_data.iloc[0]["ticker"]
+        import canalyst_candas.candas_datareader as cdr
+
+        df = cdr.regress_dataframe_groups(
+            df_data, y_name=y_name, return_grouped=return_grouped
+        )
+        df = df.dropna()
+        df["ticker"] = ticker
+        return df
+
     # shows a tree for the given ticker and time series
     def create_model_map(
         self,
@@ -880,6 +984,9 @@ class ModelSet:
             )
         return df  # [['time_series_name','time_series_description','category_slug']]
 
+    def common_time_series(self):
+        return self._common_time_series_names
+
     # creates the default dataframes features and Drivers
     def get_featurelibrary(self, col="time_series_name"):
         if type(self.ticker_list) is list:
@@ -895,24 +1002,25 @@ class ModelSet:
 
                 df = md._model_frame
 
+                if self.mo_only == True:
+                    df = df.loc[df["time_series_name"].str.startswith("MO_")]
+
                 list_df.append(df)
+
                 if df is not None:
                     list_rows = list(set(list(df[col])))
                     list_all.append(list_rows)
 
             df = pd.concat(list_df)
 
+            res = list(reduce(lambda i, j: i & j, (set(x) for x in list_all)))
+            self._common_time_series_names = res
+
             if self.allow_nulls == False:
-                res = list(reduce(lambda i, j: i & j, (set(x) for x in list_all)))
-                self._common_time_series_names = res
                 df = df_filter(df, "time_series_name", res)
                 self._features = df
             else:
-                if self.mo_only == True:
-                    df = df.loc[df["time_series_name"].str.startswith("MO_")]
-                    self._features = df
-                else:
-                    self._features = df
+                self._features = df
 
             if self.extract_drivers == True:
                 self.drivers = df[df["is_driver"] == 1]
@@ -946,6 +1054,7 @@ class ModelSet:
         n_periods="",
         mrq_notation=False,
         unit_type="",
+        category="",
         warning=True,
         ticker="",
     ):
@@ -967,6 +1076,7 @@ class ModelSet:
             n_periods,
             mrq_notation,
             unit_type,
+            category,
             warning,
         )
 
@@ -1968,7 +2078,7 @@ class Model:
             ]
         return df
 
-    # MODELSET model_frame
+    # MODEL model_frame
     def model_frame(
         self,
         time_series_name="",
@@ -1981,6 +2091,7 @@ class Model:
         n_periods=12,
         mrq_notation=False,
         unit_type="",
+        category="",
         warning=True,
     ):
         return filter_dataset(
@@ -1995,6 +2106,7 @@ class Model:
             n_periods,
             mrq_notation,
             unit_type,
+            category,
             warning,
         )
 
