@@ -1089,7 +1089,7 @@ def mrq_df(df):
         values="value",
         index=[
             "name_index",
-            "model_name",
+            # "model_name",
             "ticker",
             "category",
             "time_series_name",
@@ -1104,7 +1104,7 @@ def mrq_df(df):
 
     name_cols = [
         "name_index",
-        "model_name",
+        # "model_name",
         "ticker",
         "category",
         "time_series_name",
@@ -1132,7 +1132,7 @@ def pivot_df(df, mrq_notation):
         df,
         values="value",
         index=[
-            "model_name",
+            # "model_name",
             "ticker",
             "name_index",
             "category",
